@@ -9,7 +9,7 @@ function(name)
     Weka_interfaces[[Java_class_base_name(name)]] <- meta
     
     out <- function(x, control = NULL) {
-        stemmer <- .jnew(name)
+        stemmer <- Weka_object_for_name(name)
         control <- as.character(control)
         if(length(control)) {
             if(.has_method(stemmer, "setOptions"))
